# The Font Program

The font program, stored in the `fpgm` table, always contains the same 10 functions in every font hinted with FLS5. Only function 0 contains values based on the specific font’s settings.

0. [Deactivate grid fitting, set stem snap and delta base](fdef0.md)
1. [Round a stem](fdef1.md)
2. [Round a number of stems](fdef2.md)
3. [Double Link without stem](fdef3.md)
4. [Double Link with stem](fdef4.md)
5. [Function 5](fdef5.md) (unused)
6. [Round a zone position and vertical width](fdef6.md)
7. [Round a number of zones](fdef7.md)
8. [Apply pixel jumps to a stem](fdef8.md)
9. [Function 9](fdef9.md) (unused)
